Index: tests/RecordTestUtils.h |
diff --git a/tests/RecordTestUtils.h b/tests/RecordTestUtils.h |
index 8243089e5de76e565cddede5104601438b2e1ddb..e4421fab5265961826cefdbd1a60a4756a6be0bc 100644 |
--- a/tests/RecordTestUtils.h |
+++ b/tests/RecordTestUtils.h |
@@ -11,10 +11,10 @@ |
#include "SkRecord.h" |
#include "SkRecords.h" |
// If the command we're reading is a U, set ptr to it, otherwise set it to NULL. |
template <typename U> |
struct ReadAs { |
- ReadAs() : ptr(NULL), type(SkRecords::Type(~0)) {} |
+ ReadAs() : ptr(nullptr), type(SkRecords::Type(~0)) {} |
const U* ptr; |
SkRecords::Type type; |
@@ -11,10 +11,10 @@ |
#include "SkRecord.h" |
#include "SkRecords.h" |
-// If the command we're reading is a U, set ptr to it, otherwise set it to NULL. |
+// If the command we're reading is a U, set ptr to it, otherwise set it to nullptr. |
template <typename U> |
struct ReadAs { |